#include <LCDWIKI_GUI.h> //Core graphics library
#include <LCDWIKI_KBV.h> //Hardware-specific library
#include "DHT.h"
#include "RF24.h"
#include <DS1307.h>
#include <Wire.h>

#define DHTPIN 2  

#define DHTTYPE DHT22 
DHT dht(DHTPIN, DHTTYPE);

RF24 myRadio (7, 8);
byte addresses[][6] = {"0"};

LCDWIKI_KBV ecranlcd(ILI9486,40,38,39,-1,41); //model,cs,cd,wr,rd,reset

DS1307 rtc(SDA, SCL);

float Temp, Humi;
float TempE = 0.0;
float HumiE = 0.0;

#define NOIR   0x0000
#define BLEU    0x001F
#define ROUGE     0xF800
#define VERT   0x07E0
#define CYAN    0x07FF
#define MAGENTA 0xF81F
#define JAUNE  0xFFE0
#define BLANC   0xFFFF
#define ORANGE   0xFCA0
#define BLEUCLAIR  0x051F

struct package
{
  float temperature ;
  float humidity ;
};

typedef struct package Package;
Package data;



void setup() {
  
  Wire.begin();  
  rtc.begin();   
  Serial.begin(9600);
  dht.begin(); 
  ecranlcd.Init_LCD();

  //Parametrer date et heure
  //rtc.setDOW(TUESDAY);
  //rtc.setTime(20, 11, 00);
  //rtc.setDate(24, 9, 2019); //Jour Mois Année
  
  startWirelessCommunication();  
  ecranlcd.Fill_Screen(NOIR);

}

void loop() {

  affichage();  
}

void affichage()
{    
    checkForWirelessData();  
    String heurecomplete = rtc.getTimeStr();
    String h = heurecomplete.substring(0,2);
    String m = heurecomplete.substring(3,5);
    String s = heurecomplete.substring(6,8);

    String datecomplete = rtc.getDateStr();
    String jj = datecomplete.substring(0,2);
    String mm = datecomplete.substring(3,5);
    String aa = datecomplete.substring(6,10);

    String jour = rtc.getDOWStr();
    String jourfr;

    Temp = dht.readTemperature();
    Humi = dht.readHumidity();
    
    if (jour == "Monday")
      {
        jourfr = "Lundi";
      }
    else if (jour == "Tuesday")
      {
        jourfr = "Mardi";
      }
    else if (jour == "Wednesday")
      {
        jourfr = "Mercredi";
      }
    else if (jour == "Thursday")
      {
        jourfr = "Jeudi";
      }
    else if (jour == "Friday")
      {
        jourfr = "Vendredi";
      }
    else if (jour == "Saturday")
      {
        jourfr = "Samedi";
      }
    else if (jour == "Sunday")
      {
        jourfr = "Dimanche";
      }
      
  ecranlcd.Set_Rotation(1); 
  
  ecranlcd.Set_Draw_color(BLEUCLAIR);
  ecranlcd.Draw_Rectangle(1, 1, 479, 120);
  ecranlcd.Draw_Rectangle(2, 2, 478, 318);
  ecranlcd.Draw_Rectangle(3, 3, 477, 317);    
  ecranlcd.Draw_Rectangle(1, 121, 479, 220);  
  ecranlcd.Draw_Rectangle(1, 221, 479, 319);
  ecranlcd.Draw_Line(280, 121, 280, 319);
  ecranlcd.Draw_Line(281, 121, 281, 319);
  
  ecranlcd.Set_Text_Mode(0);
  ecranlcd.Set_Text_colour(0xFF9E);
  ecranlcd.Set_Text_Back_colour(NOIR);
  ecranlcd.Set_Text_Size(3);
  ecranlcd.Print_String(jourfr, 10, 10);
  ecranlcd.Print_String(jj + "/" + mm + "/" + aa, 280, 10);
  ecranlcd.Set_Text_colour(BLANC);
  ecranlcd.Set_Text_Size(7);
  ecranlcd.Print_String(h + ":" + m + ":" + s, 80, 50);
  
  ecranlcd.Set_Text_Size(3);
  ecranlcd.Set_Text_colour(0x3E80);
  ecranlcd.Print_String("IN:", 10, 160);
  ecranlcd.Set_Text_colour(0xF904);
  ecranlcd.Print_String("OUT:", 10, 260);
  
  ecranlcd.Set_Text_Size(5);
  ecranlcd.Set_Text_colour(JAUNE);
  ecranlcd.Print_Number_Float(Temp, 1, 100, 150, '.', 0, ' ');
  ecranlcd.Set_Draw_color(JAUNE);
  ecranlcd.Draw_Circle(230, 145, 5);
  ecranlcd.Draw_Circle(230, 145, 4);
  ecranlcd.Print_String("C", 240, 150);  
  ecranlcd.Print_Number_Float(Humi, 1, 300, 150, '.', 0, ' ');
  ecranlcd.Print_String("%", 430, 150);

  ecranlcd.Set_Text_colour(ORANGE);
  ecranlcd.Print_Number_Float(TempE, 1, 100, 250, '.', 0 , ' ');
  ecranlcd.Set_Draw_color(ORANGE);
  ecranlcd.Draw_Circle(230, 245, 5);
  ecranlcd.Draw_Circle(230, 245, 4);
  ecranlcd.Print_String("C", 240, 250);
  ecranlcd.Print_Number_Float(HumiE, 1, 300, 250, '.', 0, ' ');
  ecranlcd.Print_String("%", 430, 250);
}


void startWirelessCommunication()
{
  myRadio.begin(); 
  myRadio.setChannel(115); 
  myRadio.setPALevel(RF24_PA_MAX);
  myRadio.setDataRate( RF24_250KBPS ) ; 
  myRadio.openReadingPipe(1, addresses[0]);
  myRadio.startListening();
  delay(100);
}

void checkForWirelessData()
{
    if ( myRadio.available()) 
  {
    while (myRadio.available())
    {
      myRadio.read( &data, sizeof(data) );
      TempE = data.temperature;
      HumiE = data.humidity;
    }
    Serial.print("\nPackage:");
    Serial.print("\n");
    Serial.println(data.temperature);
    Serial.println(data.humidity);
  } 

}
